
import React, { useState, useEffect } from "react";
import { Swiper, SwiperSlide } from "swiper/react";
import "swiper/css";
import "swiper/css/navigation";
import { Navigation } from "swiper/modules";
import { toast } from "react-toastify";

const Hero = () => {
  const defaultImages = [
    "/banner1.jpg",
    "/banner2.jpg",
    "/banner3.jpg",
  ]; 

  const [images, setImages] = useState(() => {
    const savedImages = localStorage.getItem("heroImages");
    return savedImages ? JSON.parse(savedImages) : defaultImages;
  });

  // Save images to localStorage
  useEffect(() => {
    localStorage.setItem("heroImages", JSON.stringify(images));
  }, [images]);

  // Handle file upload
  const handleAddImage = (event) => {
    const file = event.target.files[0];
    if (file) {
      const reader = new FileReader();
      reader.onload = (e) => {
        setImages([...images, e.target.result]);
        toast.success("Image added successfully!");
      };
      reader.readAsDataURL(file);
    }
  };

  const handleUpdateImage = (index) => {
    const fileInput = document.createElement("input");
    fileInput.type = "file";
    fileInput.accept = "image/*";
    fileInput.onchange = (event) => {
      const file = event.target.files[0];
      if (file) {
        const reader = new FileReader();
        reader.onload = (e) => {
          const updatedImages = [...images];
          updatedImages[index] = e.target.result;
          setImages(updatedImages);
          toast.success("Image updated successfully!");
        };
        reader.readAsDataURL(file);
      }
    };
    fileInput.click();
  };

  const handleRemoveImage = (index) => {
    const updatedImages = images.filter((_, i) => i !== index);
    setImages(updatedImages.length > 0 ? updatedImages : defaultImages); 
    toast.success("Image removed successfully!");
  };

  return (
    <div>
      <Swiper modules={[Navigation]} navigation loop={true} className="rounded-xl overflow-hidden shadow-lg mb-6" spaceBetween={10} slidesPerView={1}>
        {images.map((image, index) => (
          <SwiperSlide key={index} className="relative">
            <img src={image} alt={`Slide ${index + 1}`} className="w-full lg:h-[600px] md:h-[350px] object-cover" />
            <div className="flex items-center space-x-2">
              <button onClick={() => handleUpdateImage(index)} className="absolute top-4 right-4 bg-blue-500 text-white px-4 py-2 rounded-full hover:bg-blue-600 cursor-pointer">
                Update
              </button>
              <button onClick={() => handleRemoveImage(index)} className="absolute top-4 right-24 bg-red-500 mr-6 text-white px-4 py-2 rounded-full hover:bg-red-600 cursor-pointer">
                Remove
              </button>
            </div>
          </SwiperSlide>
        ))}
      </Swiper>

      <div className="flex items-center space-x-2 mt-3">
        <input type="file" accept="image/*" onChange={handleAddImage} className="border border-gray-300 rounded-lg px-3 py-2 w-60 hidden" id="fileInput" />
        <label htmlFor="fileInput" className="bg-white text-black px-4 py-2 rounded-lg hover:bg-gray-300 cursor-pointer">
          Add Image
        </label>
      </div>
    </div>
  );
};


export default Hero;