import React, { useState } from "react";
import { motion } from "framer-motion";
import Hero from "../components/Hero";
import Coach from "../components/Coach";
import Events from "../components/Events";

const AdminDashboard = () => {
  const [activeTab, setActiveTab] = useState("hero");

  return (
    <div className="min-h-screen w-full bg-black text-white">
      <motion.div className="w-full">
        <div className="bg-gray-900 p-6 shadow-lg">
          <h1 className="text-3xl font-bold tracking-wide">Admin Dashboard</h1>
        </div>

        {/* Tab Navigation */}
        <div className="flex justify-center mt-6 space-x-4">
          {[
            { label: "Hero", value: "hero" },
            { label: "Coach", value: "coach" },
            { label: "Events", value: "calendar" },
          ].map((tab) => (
            <button
              key={tab.value}
              onClick={() => setActiveTab(tab.value)}
              className={`px-6 py-3 rounded-full text-sm cursor-pointer font-medium transition-all shadow-md focus:outline-none ${
                activeTab === tab.value
                  ? "bg-white text-black"
                  : "bg-gray-700 text-gray-300 hover:bg-gray-600"
              }`}
            >
              {tab.label}
            </button>
          ))}
        </div>
        {/* Tab Content */}
        <motion.div key={activeTab} className="p-8">
          {/* Hero Content */}
          {activeTab === "hero" && <Hero />}
          {/* Coach Content */}
          {activeTab === "coach" && <Coach />}

          {/* Events Content */}
          {activeTab === "calendar" && <Events />}
        </motion.div>
      </motion.div>
    </div>
  );
};

export default AdminDashboard;
